##  Overview
The following examples explain how to configure automations for specific triggers. For a complete list of triggers, see [Triggers](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758d6af7a441014b829a7547e83bfd4__triggers).
Automation Examples: Use Cases by Triggers Trigger | Examples
---|---
Fact sheet created |
  * [Creating Subscriptions for Specific Users on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_subscriptions_for_specific_users_on_newly_created_fact_sheets)
  * [Creating Subscriptions for Fact Sheet Creators on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_subscriptions_for_fact_sheet_creators_on_newly_created_fact_sheets)
  * [Creating an Action Item for Fact Sheet Creators on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_an_action_item_for_fact_sheet_creators_on_newly_created_fact_sheets)
  * [Adding Tags or Setting Single-Select Field Values on Newly Created Fact Sheets](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__adding_tags_or_setting_single-select_field_values_on_newly_created_fact_sheets)


Fact sheet field changed |
  * [Changing a Field Value Based on Another Field Value](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__changing_a_field_value_based_on_another_field_value)
  * [Creating an Action Item on a Field Change](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_an_action_item_on_a_field_change)


Lifecycle phase changed |
  * [Assigning an Action Item to Subscriptions (Fixed Users) on Lifecycle Phase Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__assigning_an_action_item_to_subscriptions_fixed_users_on_lifecycle_phase_changes)
  * [Adding or Removing a Tag on Lifecycle Phase Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__adding_or_removing_a_tag_on_lifecycle_phase_changes)
  * [Setting a Single-Select Field on Lifecycle Phase Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__setting_a_single-select_field_on_lifecycle_phase_changes)


Quality state changed |
  * [Assigning an Action Item to Subscriptions on Quality State Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__assigning_an_action_item_to_subscriptions_on_quality_state_changes)
  * [Assigning an Action Item to Specific Users on Quality State Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__assigning_an_action_item_to_specific_users_on_quality_state_changes)
  * [Adding a Tag or Setting a Single-Select Field Value on Quality Seal Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__adding_a_tag_or_setting_a_single-select_field_value_on_quality_seal_changes)


Tag added or removed |
  * [Creating an Action Item for Subscriptions on Tag Addition or Removal](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_an_action_item_for_subscriptions_on_tag_addition_or_removal)
  * [Creating an Action Item for Specific Users on Tag Addition or Removal](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_an_action_item_for_specific_users_on_tag_addition_or_removal)
  * [Adding a Subscription on Tag Addition or Removal](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__adding_a_subscription_on_tag_addition_or_removal)
  * [Conditional Tagging](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__conditional_tagging)


Subscription added or removed |
  * [Creating an Action Item for Subscriptions on Subscription Addition or Removal](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_an_action_item_for_subscriptions_on_subscription_addition_or_removal)
  * [Creating an Action Item for Fixed Users on Subscription Addition or Removal](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__creating_an_action_item_for_fixed_users_on_subscription_addition_or_removal)
  * [Adding a Subscription on Subscription Addition or Removal](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__adding_a_subscription_on_subscription_addition_or_removal)
  * [Tagging on Subscription Changes](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers?locale=en-US&state=PRODUCTION&version=CLOUD#loioc50149b2a6da44f2b7e1b43f269bdd5f__tagging_on_subscription_changes)


Triggers on relations: relation added, changed, or removed |
  * [Synchronizing Subscriptions Across Related Fact Sheets (Subscription Inheritance)](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD "Configure automations with scripts to automatically synchronize subscriptions across related fact sheets.")
  * [Breaking Application Quality Seals when Initiatives Reach End of Life](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life?locale=en-US&state=PRODUCTION&version=CLOUD "Configure automations with scripts to automatically break quality seals on applications when related initiatives reach End of Life.")
  * [Propagating Business Context Relations to Parent Applications (Relation Inheritance)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD "Configure automations with scripts to automatically propagate relations from business contexts to parent applications.")




